#
# spec file for package python-colander
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2013-2019 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-colander
Version:        1.7.0
Release:        5.14
Summary:        A schema-based serialization and deserialization library
License:        BSD-4-Clause AND ZPL-2.1 AND MIT
URL:            https://github.com/Pylons/colander
Source:         https://files.pythonhosted.org/packages/source/c/colander/colander-%{version}.tar.gz
# PATCH-FIX-UPSTREAM fix-tests.patch gh#Pylons/colander#210 mcepl@suse.com
# Fix tests to work with pytest (and nose2) as well
Patch0:         fix-tests.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module translationstring}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-iso8601
Requires:       python-translationstring
Obsoletes:      python2-colander-doc
Obsoletes:      python2-colander-lang
Obsoletes:      python3-colander-doc
Obsoletes:      python3-colander-lang
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module coverage}
BuildRequires:  %{python_module hupper}
BuildRequires:  %{python_module iso8601}
BuildRequires:  %{python_module plaster-pastedeploy}
BuildRequires:  %{python_module plaster}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
An extensible package which can be used to:

- deserialize and validate a data structure composed of strings,
  mappings, and lists.

- serialize an arbitrary data structure to a data structure composed
  of strings, mappings, and lists.

%prep
%setup -q -n colander-%{version}
%autopatch -p1

%build
%python_build

%install
%python_install
%find_lang colander
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE.txt
%doc CHANGES.rst README.rst
%{python_sitelib}/colander*

%changelog
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Obsolete the lang subpackage to avoid conflicts
- Do not generate docu twice, it is provided online by
  upstream so we don't have to bother really at all
* Mon Apr 20 2020 Matej Cepl <mcepl@suse.com>
- Eliminate complicated py2k constructs
* Fri Apr 17 2020 Matej Cepl <mcepl@suse.com>
- Add fix-tests.patch allowing use of pytest (gh#Pylons/colander#210)
* Mon Oct 14 2019 Matej Cepl <mcepl@suse.com>
- Replace %%fdupes -s with plain %%fdupes; hardlinks are better.
* Thu Feb  7 2019 Hans-Peter Jansen <hpj@urpla.net>
- Update to 1.7.0 (2019-02-01), also fixes bsc#1123996 (CVE-2017-18361)
  + The URL validator regex has been updated to no longer be
    vulnerable to a catastrophic backtracking that would have led to
    an infinite loop.
    See https://github.com/Pylons/colander/pull/323
    and https://github.com/Pylons/colander/issues/290.
    With thanks to Przemek (https://github.com/p-m-k).
  + This does change the behaviour of the URL validator and it no
    longer supports file:// URI scheme
    (https://tools.ietf.org/html/rfc8089). Users that wish to validate
    file:// URI’s should change their validator to use
    colander.file_uri instead.
  + It has also dropped support for alternate schemes outside of
    http/ftp (and their secure equivelants). Please let us know if we
    need to relax this requirement.
  + CVE-ID: CVE-2017-18361
  + The Email validator has been updated to use the same regular
    expression that is used by the WhatWG HTML specification, thereby
    increasing the email addresses that will validate correctly from
    web forms submitted.
    See https://github.com/Pylons/colander/pull/324
    and https://github.com/Pylons/colander/issues/283
  + Number once again will allow you to serialize None to colander.null,
    this reverts an accidental revert.
    See https://github.com/Pylons/colander/issues/204#issuecomment-459556100
  + Integer SchemaType now supports an optional strict mode that will
    validate that the number is an integer, rather than silently accepting
    floats and truncating.
    See https://github.com/Pylons/colander/pull/322
    and https://github.com/Pylons/colander/issues/292
- Update to 1.6.0 (2019-01-31)
  + Support custom format strings on DateTime and Date fields.
    See https://github.com/Pylons/colander/pull/318
  + Support sub-second precision on Time fields if provided.
    See https://github.com/Pylons/colander/pull/319
  + Format Python code of colander to conform to the PEP 8 style guide.
    Add some linters (flake8, black and other) into tox.ini.
    See https://github.com/Pylons/colander/pull/320
- Update to 1.5.1 (2018-09-10)
  + Support deserializing colander.drop and colander.required.
    See https://github.com/Pylons/colander/pull/304
- Update to 1.5.0 (2018-09-07)
  + Drop Python 3.3 support. Add PyPy3 and Python 3.7 as allowed failures.
    See https://github.com/Pylons/colander/pull/309
  + Fix email validation to not allow all ASCII characters between + and /.
    This prevents email addresses like ‘foo1,foo2@bar.baz’ from being
    validated, which would be handled as multiple email addresses by
    subsequent tools.
    See https://github.com/Pylons/colander/pull/315
  + Add support for enum.Enum objects.
    See https://github.com/Pylons/colander/pull/305
  + Recompiled language translations and updated de and el locales.
    See https://github.com/Pylons/colander/pull/284
    and https://github.com/Pylons/colander/pull/314
* Wed Dec  5 2018 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality of descriptions.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu May 24 2018 toddrme2178@gmail.com
- spec file cleanups
* Tue Sep 19 2017 bruno@ioda-net.ch
- Update to upstream 1.4
- Backport python3 to singlespec + lang package
* Thu Feb  9 2017 hpj@urpla.net
- Update to version 1.3.2: initial build for python3
* Fri Feb  6 2015 hpj@urpla.net
- Update to version 1.0
  to many changes to list here, check:
  https://pypi.python.org/pypi/colander/1.0
* Mon Aug  5 2013 hpj@urpla.net
- Version 1.0a5: initial build
